==> qbittorrent_4.2.3.orig.tar.xz: qbittorrent-4.2.3/src/gui/search/pluginsourcedialog.cpp <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2006  Christophe Dumez <chris@qbittorrent.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#include "pluginsourcedialog.h"

#include "ui_pluginsourcedialog.h"
#include "utils.h"

PluginSourceDialog::PluginSourceDialog(QWidget *parent)
    : QDialog(parent)
    , m_ui(new Ui::PluginSourceDialog())
{
    m_ui->setupUi(this);
    setAttribute(Qt::WA_DeleteOnClose);

    Utils::Gui::resize(this);
    show();
}

PluginSourceDialog::~PluginSourceDialog()
{
    delete m_ui;
}

void PluginSourceDialog::on_localButton_clicked()
{
    emit askForLocalFile();
    close();
}

void PluginSourceDialog::on_urlButton_clicked()
{
    emit askForUrl();
    close();
}

==> qbittorrent_4.4.1.orig.tar.xz: qbittorrent-4.4.1/src/gui/search/pluginsourcedialog.cpp <==
/*
 * Bittorrent Client using Qt and libtorrent.
 * Copyright (C) 2006  Christophe Dumez <chris@qbittorrent.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * In addition, as a special exception, the copyright holders give permission to
 * link this program with the OpenSSL project's "OpenSSL" library (or with
 * modified versions of it that use the same license as the "OpenSSL" library),
 * and distribute the linked executables. You must obey the GNU General Public
 * License in all respects for all of the code used other than "OpenSSL".  If you
 * modify file(s), you may extend this exception to your version of the file(s),
 * but you are not obligated to do so. If you do not wish to do so, delete this
 * exception statement from your version.
 */

#include "pluginsourcedialog.h"

#include "gui/utils.h"
#include "ui_pluginsourcedialog.h"

#define SETTINGS_KEY(name) "SearchPluginSourceDialog/" name

PluginSourceDialog::PluginSourceDialog(QWidget *parent)
    : QDialog(parent)
    , m_ui(new Ui::PluginSourceDialog)
    , m_storeDialogSize(SETTINGS_KEY("Size"))
{
    m_ui->setupUi(this);
    setAttribute(Qt::WA_DeleteOnClose);

    Utils::Gui::resize(this, m_storeDialogSize);
    show();
}

PluginSourceDialog::~PluginSourceDialog()
{
    m_storeDialogSize = size();
    delete m_ui;
}

void PluginSourceDialog::on_localButton_clicked()
{
    emit askForLocalFile();
    close();
}

void PluginSourceDialog::on_urlButton_clicked()
{
    emit askForUrl();
    close();
}
